@@ -20,11 +20,10 @@
 #ifndef __GCONF_STOCK_ICONS_H__
 #define __GCONF_STOCK_ICONS_H__
 
-#include <gtk/gtkstock.h>
+#include <gtk/gtk.h>
 
-#define GCONF_STOCK_ABOUT 	"gconf-about"
 #define STOCK_BOOKMARK		"stock_bookmark"
-#define STOCK_ADD_BOOKMARK	"stock_add-bookmark"
+#define STOCK_ADD_BOOKMARK	"bookmark-new"
 #define STOCK_EDIT_BOOKMARK	"stock_edit-bookmark"
 
 void gconf_stock_icons_register (void);
